#include "StdAfx.h"
#include "GSXmlWriter.h"


CGSXmlWriter::CGSXmlWriter(void)
{
}

CGSXmlWriter::~CGSXmlWriter(void)
{
}

HRESULT CGSXmlWriter::Initialize(LPCTSTR lpFileName)
{
    HRESULT hr;
  
	 //Open writeable output stream
    if (FAILED(hr = SHCreateStreamOnFile(lpFileName, STGM_CREATE | STGM_WRITE, &pOutFileStream)))
    {
        wprintf(L"Error creating file writer, error is %08.8lx", hr);
        return hr;
    }

    if (FAILED(hr = CreateXmlWriter(__uuidof(IXmlWriter), (void**) &pWriter, NULL)))
    {
        wprintf(L"Error creating xml writer, error is %08.8lx", hr);
        return hr;
    }

    if (FAILED(hr = pWriter->SetOutput(pOutFileStream)))
    {
        wprintf(L"Error, Method: SetOutput, error is %08.8lx", hr);
        return hr;
    }

    if (FAILED(hr = pWriter->SetProperty(XmlWriterProperty_Indent, TRUE)))
    {
        wprintf(L"Error, Method: SetProperty XmlWriterProperty_Indent, error is %08.8lx", hr);
        return hr;
    }

    if (FAILED(hr = pWriter->WriteStartDocument(XmlStandalone_Omit)))
    {
        wprintf(L"Error, Method: WriteStartDocument, error is %08.8lx", hr);
        return hr;
    }

	return S_OK;
}

bool CGSXmlWriter::WriteProcessingInstruction (LPCTSTR lpName, LPCTSTR lpText)
{
	HRESULT hr;
	USES_CONVERSION;

	if (FAILED(hr = pWriter->WriteProcessingInstruction(T2CW(lpName), T2CW(lpText))))
	{
	  wprintf(L"Error, Method: WriteProcessingInstruction, error is %08.8lx", hr);
	  return false;
	}

	return true;
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, LPCTSTR lpValue)
{
	HRESULT hr;
	USES_CONVERSION;

    if (FAILED(hr = pWriter->WriteStartElement(NULL, T2CW(lpName), NULL)))
    {
        wprintf(L"Error, Method: WriteStartElement, error is %08.8lx", hr);
        return false;
    }
    if (FAILED(hr = pWriter->WriteString(T2CW(lpValue))))
    {
        wprintf(L"Error, Method: WriteString, error is %08.8lx", hr);
        return false;
    }
    if (FAILED(hr = pWriter->WriteFullEndElement()))
    {
        wprintf(L"Error, Method: WriteFullEndElement, error is %08.8lx", hr);
        return false;
    }
    if (FAILED(hr = pWriter->WriteWhitespace(L"\n")))
    {
        wprintf(L"Error, Method: WriteWhitespace, error is %08.8lx", hr);
        return false;
    }
/*
	if (FAILED(hr = pWriter->WriteElementString(NULL, lpName, NULL, lpValue)))
	{
	  wprintf(L"Error, Method: WriteElementString, error is %08.8lx", hr);
	  return false;
	}
	if (FAILED(hr = pWriter->WriteFullEndElement()))
	{
	  wprintf(L"Error, Method: WriteFullEndElement, error is %08.8lx", hr);
	  return false;
	}
	if (FAILED(hr = pWriter->WriteWhitespace(L"\n")))
	{
	  wprintf(L"Error, Method: WriteWhitespace, error is %08.8lx", hr);
	  return false;
	}*/

	return true;
}


bool CGSXmlWriter::WriteStartElement(LPCTSTR lpName)
{
	HRESULT hr;
	USES_CONVERSION;

	if (FAILED(hr = pWriter->WriteStartElement(NULL, T2CW(lpName), NULL)))
    {
        wprintf(L"Error, Method: WriteStartElement, error is %08.8lx", hr);
        return false;
    }
	return true;
}

bool CGSXmlWriter::WriteFullEndElement(void)
{
	HRESULT hr;

	if (FAILED(hr = pWriter->WriteFullEndElement()))
	{
	  wprintf(L"Error, Method: WriteFullEndElement, error is %08.8lx", hr);
	  return false;
	}
	if (FAILED(hr = pWriter->WriteWhitespace(L"\n")))
	{
	  wprintf(L"Error, Method: WriteWhitespace, error is %08.8lx", hr);
	  return false;
	}

	return true;
}

bool CGSXmlWriter::Close(void)
{
	HRESULT hr;

    // WriteEndDocument closes any open elements or attributes
    if (FAILED(hr = pWriter->WriteEndDocument()))
    {
        wprintf(L"Error, Method: WriteEndDocument, error is %08.8lx", hr);
        return false;
    }
    if (FAILED(hr = pWriter->Flush()))
    {
        wprintf(L"Error, Method: Flush, error is %08.8lx", hr);
        return false;
    }

	return true;
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, int value)
{
	CString str;
	str.Format(_T("%d"), value);
	return WriteElementValue(lpName, str);
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, long value)
{
	CString str;
	str.Format(_T("%d"), value);
	return WriteElementValue(lpName, str);
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, DWORD value)
{
	CString str;
	str.Format(_T("%d"), value);
	return WriteElementValue(lpName, str);
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, short value)
{
	CString str;
	str.Format(_T("%d"), value);
	return WriteElementValue(lpName, str);
}

bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, float value)
{
	CString str;
	str.Format(_T("%f"), value);
	return WriteElementValue(lpName, str);
}
bool CGSXmlWriter::WriteElementValue(LPCTSTR lpName, double value)
{
	CString str;
	str.Format(_T("%g"), value);
	return WriteElementValue(lpName, str);
}
